@@ -35,7 +35,8 @@ def searchCVE(
         limit: Optional[int] = None,
         delay: Optional[float] = None,
         key: Optional[str] = None,
-        verbose: Optional[bool] = None
+        verbose: Optional[bool] = None,
+        proxies: Optional[Dict] = None
 ) -> List[CVE]:
     """Build and send GET request then return list of objects containing a collection of CVEs. For more information on the parameters available, please visit https://nvd.nist.gov/developers/vulnerabilities 
 
@@ -155,8 +156,10 @@ def searchCVE(
         key)
 
     # raw is the raw dictionary response.
-    raw = __get('cve', headers, parameters, limit, delay)
+    raw = __get('cve', headers, parameters, limit, delay, proxies)
     cves = []
+    if not raw:
+        return cves
     # Generates the CVEs into objects for easy access and appends them to self.cves
     for eachCVE in raw['vulnerabilities']:
         cves.append(__convert('cve', eachCVE['cve']))
@@ -192,7 +195,8 @@ def searchCVE_V2(
         limit: Optional[int] = None,
         delay: Optional[float] = None,
         key: Optional[str] = None,
-        verbose: Optional[bool] = None
+        verbose: Optional[bool] = None,
+        proxies: Optional[Dict] = None
 ) -> Generator[List[CVE], Tuple[str, Any], None]:
     """Build and send GET request then return list of objects containing a collection of CVEs. For more information on the parameters available, please visit https://nvd.nist.gov/developers/vulnerabilities 
 
@@ -313,7 +317,9 @@ def searchCVE_V2(
 
     # Send the GET request. Get a generator object that returns batched
     # responses converted to dictionaries
-    for batch in __get_with_generator('cve', headers, parameters, limit, delay):
+    for batch in __get_with_generator('cve', headers, parameters, limit, delay, proxies):
+        if not batch:
+            continue
         for eachCVE in batch['vulnerabilities']:
             yield __convert('cve', eachCVE['cve'])
 
